package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.TransactionDetails;

/**
 * 交易明细记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface TransactionDetailsMapper 
{
    /**
     * 查询交易明细记录
     * 
     * @param id 交易明细记录主键
     * @return 交易明细记录
     */
    public TransactionDetails selectTransactionDetailsById(Long id);

    /**
     * 查询交易明细记录列表
     * 
     * @param transactionDetails 交易明细记录
     * @return 交易明细记录集合
     */
    public List<TransactionDetails> selectTransactionDetailsList(TransactionDetails transactionDetails);

    /**
     * 新增交易明细记录
     * 
     * @param transactionDetails 交易明细记录
     * @return 结果
     */
    public int insertTransactionDetails(TransactionDetails transactionDetails);

    /**
     * 修改交易明细记录
     * 
     * @param transactionDetails 交易明细记录
     * @return 结果
     */
    public int updateTransactionDetails(TransactionDetails transactionDetails);

    /**
     * 删除交易明细记录
     * 
     * @param id 交易明细记录主键
     * @return 结果
     */
    public int deleteTransactionDetailsById(Long id);

    /**
     * 批量删除交易明细记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTransactionDetailsByIds(Long[] ids);

    /**
     * 查询交易明细记录列表
     *
     * @return 交易明细记录集合
     */
    public List<TransactionDetails> getTransactionDetailsList();
}
